# Theorie

Mit dieser Arbeit werden diverse Konzepte zur Überwachung maschineller Anlagen erforscht. Dabei soll ein autonomes Meldesystem aufgebaut werden, welches auf schleichende Probleme aufmerksam machen kann bzw. zur Optimierung des Betriebsablaufes beiträgt. Um dies zu erreichen müssen Messwerte erhoben, analysiert und schließlich gespeichert werden. Diese Teilschritte sind in den folgenden Unterkapiteln näher aufgeführt.

## Erfassung der Messwerte

Die Aggregation der Messwerte soll unabhängig von Modell und Auslegung der Anlage möglich sein. Es werden verschiedene Wege in Betracht gezogen und schießlich einer von diesen an einer echten Anlage getestet. Die dafür notwendigen Komponenten sollten leicht in den bestehenden Aufbau integrierbar sein.

Zunächst sollen die elektrische Versorgung, die Ströme einzelner Baugruppen und der Status der zentralen Steuerung der Anlage erfasst werden. Der Messintervall sollte klein genug sein, um zwischen den Prozessschritten der Anlage unterscheiden zu können. Bei den zu betrachtenden Kernschießanlagen ist ein Intervall unter 100ms ausreichend; jedoch sollte je nach Möglichkeit ein Interval von 20ms angestrebt werden. 

Während der Entwicklung ist es auch sinnvoll die Rohwerte der Messungen zu sichern, um den Analyseschritt mit Hilfe von echten Messwerten exemplarisch zu testen.

## Übertragung der Messwerte

Für die Übertragung von den Sensoren zur datenverarbeitenden Einheit werden Kommunikationsbusse eingesetzt, welche bereits in den Kernschießmaschinen verwendet werden. Es soll nach Möglichkeit kein weiterer Feldbus einer anderen Technologie hinzugefügt werden, um die Kosten für die Integration möglichst gering zu halten. Die einzubauenden Sensoren werden am bestehenden Feldbus angeschlossen, welcher wiederum zu einem Interfacemodul führt. Für die Koordination der Interfacemodule ist in jeder Anlage bereits eine zentrale Steuerungseinheit (SPS oder CPU genannt) zuständig. Diese Steuerungen verwenden ein meist auf Ethernet basiertes Kommunikationsprotokoll, um mit dem Rest der Anlage zu kommunizieren. [] Ihre Kommunikationspartner können zum Beispiel Interfacemodule, Human-Machine-Interfaces (HMI) oder andere Steuerungen aus anderen Anlagen sein. Für dieses Projekt ist neben diesen Standardkomponenten auch ein Computer (Box-PC) hinzuzufügen, welcher die Aufgabe der Verarbeitung der aufgenommenen Messwerte übernimmt.
Die SPS ist daher so zu konfigurieren, dass sie zusätzlich zu ihrer Haupaufgabe, die Anlage zu steuern, auch die Daten von den neu hinzugefügten Sensoren an den PC weiterreicht. Hierzu können zwei Methoden verwendet werden: Zum Einen kann der Box-PC die von der SPS gesammelten Messwerte periodisch abfragen und zum Anderen kann die SPS die Daten selbstständig zum PC übermitteln. In beiden Fällen muss jedoch ein Protokoll verwendet werden, welches von beiden Seiten verwendet werden kann. Es ist beispielsweise nicht möglich ProfiNet Pakete über eine Ethernetverbindung mit einem generischen Linuxkernel zu empfangen, weil dieser nicht in der Lage ist das Echtzeitkriterium des ProfiNet-Standards zu erfüllen. []

## Datenverarbeitung

Bei der Erhebung der Messwerte entstehen viele Datenpunkte, die einzeln betrachtet keine große Aussagekraft besitzen. Der Schritt der Datenverarbeitung kombiniert die eingehenden Datenströme und extrahiert für den Endnutzer relvante Informationen. Die Verarbeitung soll auf einer PC-Platform stattfinden, so dass sie flexibel eingesetzt werden kann. Sie kann dadurch vor Ort, zum Beispiel auf einem industriellen Box-PC, oder auch über eine Netzwerkverbindung aus einem entfernten Ort durchgeführt werden. Aus sicherheitstechnischen Gründen darf die verwendete Platform nur über die erhobenen Messwerte verfügen und nicht in den ProzesDatenbildsablauf der Anlage eingreifen.

In diesem Schritt werden zuerst die Verbrauchswerte wie Ströme und Spannungen mit dem Status der Anlagensteuerung kombiniert, so dass pro Prozessschritt ein wiederholbares Datenbild entsteht. Ein Prozessschritt ist ein zeitlich begrenzter Zustand der Anlage, in der eine bestimmte Gruppe von Aktoren aktiviert wird. Dies kann beispielsweise das Einfahren des Hubtisches sein. Die elektrischen Verbräuche während dieses Schrittes können so als Funktion der Schrittnummer und Zeit nach Beginn des Vorgangs dargestellt werden. Das Datenbild besteht dann im einfachsten Fall aus Versorgungsleistungen und Strömen der 24V-Kanäle. 

Nun werden die Differenzen des Datenbildes zwischen dem Ausgangszustand und der Aktivierung eines Prozessschrittes berechnet. Dadurch können die Verbräuche der jeweiligen Prozessschritte von den Standbyströmen der inaktiven Komponenten der Anlage isoliert werden. Der Ausgangszustand sollte zeitlich nah am Messvorgang gesetzt sind, damit äußere Einflüsse wie Versorgungsspannung und Umgebungstemperatur einen geringeren Effekt auf die berechneten Differenzen haben.

Anschließend werden je nach erwartetem zeitlichen Verlaufs des Datenbilds einige Aggregationen wie Durchschnitt, Maximum oder Varianz einzelner Kanäle erhoben, um schließlich einfache Kennzahlen für diesen Schritt zu erhalten. Damit können nun Aussagen wie beispielsweise `Das für den Hubtisch zuständige Ventil hat beim zweitausendsten Aktivieren einen Strom von 1,3A verbraucht` getroffen werden.

## Datenspeicherung

Je präziser die Datenverarbeitung angesetzt ist, desto weniger Daten müssen anschließend gespeichert werden. In allen Fällen sind die zu speichernden Werte periodische Kennzahlen der einzelnen Prozessschritte, welche in einer zeitbasierten Datenbank abgelegt werden müssen. Nur wenn eine Kennzahl ein festgelegtes Limit überschreitet ist eine direkte Meldung des Wertes notwendig. 

Um eine zuverlässige Speicherung zu garantieren sollten die Daten möglichst auf mehreren unabhängigen Systemen gespeichert werden. Hierzu wird ein modularer Aufbau verwendet, der es auch ermöglicht unterschiedlichste Speichermethoden gleichzeitig zu verwenden. Schließlich ist auch eine Löschungsstategie notwendig, um zu garantieren, dass immer genug Speicherplatz für neue Daten vorhanden ist.

## Visualisierung

Die Visualisierung kann dank der vorbereiteten Datensätze im einfachsten Fall aus dem Plotten der Messreihen aus einer der Datenbanken bestehen. Je nach Bedarf kann die Visualisierung vor Ort am HMI der Anlagen erfolgen oder auch beispielsweise über einen Browser auf einem entfernten PC. Hier besteht kein großer Entwicklungsbedarf und es kann deswegen auch auf fertige universelle Visualisierungsoberflächen zurückgegriffen werden. 